aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/util.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/include/util.h b/include/util.h
index 867eb0a4..7f47d713 100644
--- a/include/util.h
+++ b/include/util.h
@@ -6,7 +6,13 @@
#include <wayland-server-protocol.h>
/**
- * Wrap i into the range [0, max[
+ * Get the current time, in milliseconds.
+ */
+
+uint32_t get_current_time_msec(void);
+
+/**
+ * Wrap i into the range [0, max]
*/
int wrap(int i, int max);